@@ -400,6 +400,15 @@ QVariant TimelineDelegateController::previousLocation() const
     return LocationUtil::location(res);
 }
 
+QDateTime TimelineDelegateController::startTime() const
+{
+    if (!m_resMgr || m_batchId.isEmpty()) {
+        return {};
+    }
+
+    return SortUtil::startDateTime(m_resMgr->reservation(m_batchId));
+}
+
 QDateTime TimelineDelegateController::effectiveEndTime() const
 {
     if (!m_resMgr || m_batchId.isEmpty()) {
@@ -489,7 +498,7 @@ KPublicTransport::JourneyRequest TimelineDelegateController::journeyRequest() co
     }
 
     KPublicTransport::JourneyRequest req;
-    req.setFrom(PublicTransport::locationFromPlace(LocationUtil::departureLocation(res), res));
+    req.setFrom(PublicTransport::locationFromPlace(LocationUtil::departureLocation(res)));
     auto depTime = QDateTime::currentDateTime();
     if (SortUtil::hasStartTime(res)) {
         depTime = std::max(depTime, SortUtil::startDateTime(res));
@@ -498,7 +507,6 @@ KPublicTransport::JourneyRequest TimelineDelegateController::journeyRequest() co
     }
     req.setDateTime(depTime);
     req.setDateTimeMode(KPublicTransport::JourneyRequest::Departure);
-    req.setDownloadAssets(true);
     req.setIncludeIntermediateStops(true);
     req.setIncludePaths(true);
     PublicTransport::selectBackends(req, m_liveDataMgr->publicTransportManager(), res);
@@ -518,7 +526,7 @@ QList<KPublicTransport::Location> TimelineDelegateController::journeyDestination
     if (!isJourneyCandidate(prevRes)) {
         return {};
     }
-    dests.push_back(PublicTransport::locationFromPlace(LocationUtil::arrivalLocation(prevRes), prevRes));
+    dests.push_back(PublicTransport::locationFromPlace(LocationUtil::arrivalLocation(prevRes)));
     while (true) {
         auto endBatchId = m_resMgr->nextBatch(prevBatchId);
         auto endRes = m_resMgr->reservation(endBatchId);
@@ -526,7 +534,7 @@ QList<KPublicTransport::Location> TimelineDelegateController::journeyDestination
             break;
         }
 
-        dests.push_back(PublicTransport::locationFromPlace(LocationUtil::arrivalLocation(endRes), endRes));
+        dests.push_back(PublicTransport::locationFromPlace(LocationUtil::arrivalLocation(endRes)));
         prevRes = endRes;
         prevBatchId = endBatchId;
     }
